package com.map;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;



public class DBAdapter {

    public static final String KEY_STREET = "street";
    public static final String KEY_LONG = "lng";
    public static final String KEY_LATI = "lat";
    public static final String KEY_NUMB = "numb";
    public static final String KEY_ROWID = "_id";

    private static final String TAG = "DBAdapter";
    private DatabaseHelper mDbHelper;
    private SQLiteDatabase mDb;
    
    /**
     * Database creation statement
     */
    private static final String DATABASE_CREATE =
            "create table location(_id integer primary key autoincrement, "
                    + "street text not null, lng text null, lat text null, numb text null);";

    private static final String DATABASE_NAME = "Number";
    private static final String DATABASE_TABLE = "location";
    private static final int DATABASE_VERSION = 1;

    private final Context mCtx;

    private static class DatabaseHelper extends SQLiteOpenHelper {

        DatabaseHelper(Context context) {
            super(context, DATABASE_NAME, null, DATABASE_VERSION);
        }

        @Override
        public void onCreate(SQLiteDatabase db) {

            db.execSQL(DATABASE_CREATE);
        }

        @Override
        public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
            Log.w(TAG, "Upgrading database from version " + oldVersion + " to "
                    + newVersion + ", which will destroy all old data");
            db.execSQL("DROP TABLE IF EXISTS address");
            onCreate(db);
        }
    }

    /**
     * Constructor - takes the context to allow the database to be
     * opened/created
     * 
     * @param ctx the Context within which to work
     */
    public DBAdapter(Context ctx) {
        this.mCtx = ctx;
    }

    /**
     * Open the notes database. If it cannot be opened, try to create a new
     * instance of the database. If it cannot be created, throw an exception to
     * signal the failure
     * 
     * @return this (self reference, allowing this to be chained in an
     *         initialization call)
     * @throws SQLException if the database could be neither opened or created
     */
    public DBAdapter open() throws SQLException {
        mDbHelper = new DatabaseHelper(mCtx);
        mDb = mDbHelper.getWritableDatabase();
        return this;
    }
    
    public void close() {
        mDbHelper.close();
    }


    /**
     * Create a new note using the title and body provided. If the note is
     * successfully created return the new rowId for that note, otherwise return
     * a -1 to indicate failure.
     * 
     * @param title the title of the note
     * @param body the body of the note
     * @return rowId or -1 if failed
     */
    public long createAddress(String str, String pcode, String lat, String numb)
    {
    	
        ContentValues initialValues = new ContentValues();
        initialValues.put(KEY_STREET, str);
        initialValues.put(KEY_LONG, pcode);
        initialValues.put(KEY_LATI, lat);
        initialValues.put(KEY_NUMB, numb);

        return mDb.insert(DATABASE_TABLE, null, initialValues);
    }

    /**
     * Delete the note with the given rowId
     * 
     * @param rowId id of note to delete
     * @return true if deleted, false otherwise
     */
    public boolean deleteAddress(long rowId) {

       return mDb.delete(DATABASE_TABLE, KEY_ROWID + "=" + rowId, null) > 0;  	
    	// Delete all notes !!
    	//return mDb.delete(DATABASE_TABLE, null, null) > 0;
    	 	
    }

    /**
     * Return a Cursor over the list of all notes in the database
     * 
     * @return Cursor over all notes
     */
    public Cursor fetchAllAddress() {

        return mDb.query(DATABASE_TABLE, new String[] {KEY_ROWID, KEY_STREET,
                KEY_LONG, KEY_LATI, KEY_NUMB}, null, null, null,null, null); 
    }
    
    public boolean deleteTable(){
    	
    	
    	return mDb.delete(DATABASE_TABLE, null, null) > 0;

    }

    /**
     * Return a Cursor positioned at the note that matches the given rowId
     * 
     * @param rowId id of note to retrieve
     * @return Cursor positioned to matching note, if found
     * @throws SQLException if note could not be found/retrieved
     */
    public Cursor fetchAddress(long rowId) throws SQLException {

        Cursor mCursor =

                mDb.query(true, DATABASE_TABLE, new String[] {KEY_ROWID,
                        KEY_STREET, KEY_LONG, KEY_LATI, KEY_NUMB}, KEY_ROWID + "=" + rowId, null,
                        null, null, null, null);
        if (mCursor != null) {
            mCursor.moveToFirst();
        }
        return mCursor;

    }

    /**
     * Update the note using the details provided. The note to be updated is
     * specified using the rowId, and it is altered to use the title and body
     * values passed in
     * 
     * @param rowId id of note to update
     * @param title value to set note title to
     * @param body value to set note body to
     * @return true if the note was successfully updated, false otherwise
     */
    public boolean updateAddress(long rowId, String str, String pcode, String lat, String numb) {
        ContentValues args = new ContentValues();
        args.put(KEY_STREET, str);
        args.put(KEY_LONG, pcode);
        args.put(KEY_LATI, lat);
        args.put(KEY_NUMB, numb);
        return mDb.update(DATABASE_TABLE, args, KEY_ROWID + "=" + rowId, null) > 0;
    }
}